@@ -26,8 +26,9 @@ RULES a
 6/6(?!~)==>/a
 6/a==>/a
 S/([a\@eA6iouOE])==>z/$1
-\@/([\@eaui6])==>/$1
-u/($vg)==>w/$1
+\@/([eaoOEu])==>i/$1
+\@/([\@i6])==>/$1
+## u/($vg)==>w/$1
 
 ENDRULES
 
