@@ -36,10 +36,10 @@ ENDRULES
 
 RULES porto
 
-oo==>uoum
-o==>oum
-am==>om
-em\b==>innhe
+oo==>uounhe
+o==>ounhe
+am==>oum
+em\b==>inhee
 v==>b
 
 ENDRULES
@@ -69,6 +69,7 @@ ENDRULES
 
 RULES/m spain
 
+^o\b==>le
 \bj==>r
 o==>cin
 es==>cins
